searchData={"items":[{"type":"behaviour","title":"Alchemind","doc":"Alchemind provides a unified interface for interacting with various LLM providers.\n\nThis module defines the base behaviours and types for working with different\nLLM implementations in a unified way, similar to LiteLLM or LlamaIndex.","ref":"Alchemind.html"},{"type":"callback","title":"Alchemind.complete/3","doc":"Completes a conversation with the LLM provider.\n\nEach provider module must implement this callback to handle completion requests.","ref":"Alchemind.html#c:complete/3"},{"type":"function","title":"Alchemind.complete/4","doc":"Completes a conversation using the specified client, with optional streaming.","ref":"Alchemind.html#complete/4"},{"type":"function","title":"Parameters - Alchemind.complete/4","doc":"- `client`: Client created with new/2\n- `messages`: List of messages in the conversation\n- `callback_or_opts`: Either a callback function for streaming or options for the request\n- `opts`: Additional options for the completion request (when callback is provided)","ref":"Alchemind.html#complete/4-parameters"},{"type":"function","title":"Options - Alchemind.complete/4","doc":"- `:model` - The model to use (required unless specified in the client)\n- `:temperature` - Controls randomness (0.0 to 2.0)\n- `:max_tokens` - Maximum number of tokens to generate","ref":"Alchemind.html#complete/4-options"},{"type":"function","title":"Examples - Alchemind.complete/4","doc":"Without streaming:\n\n    iex> {:ok, client} = Alchemind.new(Alchemind.OpenAI, api_key: \"sk-...\")\n    iex> messages = [\n    ...>   %{role: :system, content: \"You are a helpful assistant.\"},\n    ...>   %{role: :user, content: \"Hello, world!\"}\n    ...> ]\n    iex> Alchemind.complete(client, messages, model: \"gpt-4o\", temperature: 0.7)\n\nWith streaming:\n\n    iex> {:ok, client} = Alchemind.new(Alchemind.OpenAI, api_key: \"sk-...\")\n    iex> messages = [\n    ...>   %{role: :system, content: \"You are a helpful assistant.\"},\n    ...>   %{role: :user, content: \"Hello, world!\"}\n    ...> ]\n    iex> callback = fn delta -> IO.write(delta.content) end\n    iex> Alchemind.complete(client, messages, callback, model: \"gpt-4o\", temperature: 0.7)","ref":"Alchemind.html#complete/4-examples"},{"type":"function","title":"Returns - Alchemind.complete/4","doc":"- `{:ok, response}` - Successful completion with response data\n- `{:error, reason}` - Error with reason","ref":"Alchemind.html#complete/4-returns"},{"type":"callback","title":"Alchemind.complete/4","doc":"Completes a conversation with the LLM provider, with optional streaming.\n\nEach provider module must implement this callback to handle streaming completion requests.\nIf a callback is provided, streaming is enabled.","ref":"Alchemind.html#c:complete/4"},{"type":"type","title":"Alchemind.completion_choice/0","doc":"","ref":"Alchemind.html#t:completion_choice/0"},{"type":"type","title":"Alchemind.completion_error/0","doc":"","ref":"Alchemind.html#t:completion_error/0"},{"type":"type","title":"Alchemind.completion_response/0","doc":"","ref":"Alchemind.html#t:completion_response/0"},{"type":"type","title":"Alchemind.completion_result/0","doc":"","ref":"Alchemind.html#t:completion_result/0"},{"type":"type","title":"Alchemind.message/0","doc":"","ref":"Alchemind.html#t:message/0"},{"type":"callback","title":"Alchemind.new/1","doc":"Defines the client behaviour for LLM providers.\n\nEach provider must implement a client that conforms to this behaviour.","ref":"Alchemind.html#c:new/1"},{"type":"function","title":"Alchemind.new/2","doc":"Creates a new client for the specified provider.","ref":"Alchemind.html#new/2"},{"type":"function","title":"Parameters - Alchemind.new/2","doc":"- `provider`: Module implementing Alchemind provider behaviour\n- `opts`: Provider-specific options (like api_key, base_url, etc.)","ref":"Alchemind.html#new/2-parameters"},{"type":"function","title":"Examples - Alchemind.new/2","doc":"iex> Alchemind.new(Alchemind.OpenAI, api_key: \"sk-...\")\n    {:ok, %Alchemind.OpenAI.Client{...}}","ref":"Alchemind.html#new/2-examples"},{"type":"function","title":"Returns - Alchemind.new/2","doc":"- `{:ok, client}` - Client for the specified provider\n- `{:error, reason}` - Error with reason","ref":"Alchemind.html#new/2-returns"},{"type":"type","title":"Alchemind.role/0","doc":"","ref":"Alchemind.html#t:role/0"},{"type":"function","title":"Alchemind.speech/3","doc":"Converts text to speech using the specified client.","ref":"Alchemind.html#speech/3"},{"type":"function","title":"Parameters - Alchemind.speech/3","doc":"- `client`: Client created with new/2\n- `input`: Text to convert to speech\n- `opts`: Options for the speech request","ref":"Alchemind.html#speech/3-parameters"},{"type":"function","title":"Options - Alchemind.speech/3","doc":"Options are provider-specific. For OpenAI:\n\n- `:model` - OpenAI text-to-speech model to use (default: \"gpt-4o-mini-tts\")\n- `:voice` - Voice to use (default: \"alloy\")\n- `:response_format` - Format of the audio (default: \"mp3\")\n- `:speed` - Speed of the generated audio (optional)","ref":"Alchemind.html#speech/3-options"},{"type":"function","title":"Examples - Alchemind.speech/3","doc":"iex> {:ok, client} = Alchemind.new(Alchemind.OpenAI, api_key: \"sk-...\")\n    iex> Alchemind.speech(client, \"Hello, world!\", voice: \"echo\")\n    {:ok, < >}","ref":"Alchemind.html#speech/3-examples"},{"type":"function","title":"Returns - Alchemind.speech/3","doc":"- `{:ok, audio_binary}` - Successful speech generation with audio binary\n- `{:error, reason}` - Error with reason","ref":"Alchemind.html#speech/3-returns"},{"type":"callback","title":"Alchemind.speech/3","doc":"Converts text to speech.\n\nOptional callback that providers can implement to support text-to-speech conversion.","ref":"Alchemind.html#c:speech/3"},{"type":"type","title":"Alchemind.stream_callback/0","doc":"","ref":"Alchemind.html#t:stream_callback/0"},{"type":"type","title":"Alchemind.stream_delta/0","doc":"","ref":"Alchemind.html#t:stream_delta/0"},{"type":"function","title":"Alchemind.transcribe/3","doc":"Transcribes audio to text using the specified client.","ref":"Alchemind.html#transcribe/3"},{"type":"function","title":"Parameters - Alchemind.transcribe/3","doc":"- `client`: Client created with new/2\n- `audio_binary`: Binary audio data\n- `opts`: Options for the transcription request","ref":"Alchemind.html#transcribe/3-parameters"},{"type":"function","title":"Options - Alchemind.transcribe/3","doc":"Options are provider-specific. For OpenAI:\n\n- `:model` - Transcription model to use (default: \"whisper-1\")\n- `:language` - Language of the audio (default: nil, auto-detect)\n- `:prompt` - Optional text to guide the model's transcription\n- `:response_format` - Format of the transcript (default: \"json\")\n- `:temperature` - Controls randomness (0.0 to 1.0, default: 0)","ref":"Alchemind.html#transcribe/3-options"},{"type":"function","title":"Examples - Alchemind.transcribe/3","doc":"iex> {:ok, client} = Alchemind.new(Alchemind.OpenAI, api_key: \"sk-...\")\n    iex> audio_binary = File.read!(\"audio.mp3\")\n    iex> Alchemind.transcribe(client, audio_binary, language: \"en\")\n    {:ok, \"This is a transcription of the audio.\"}","ref":"Alchemind.html#transcribe/3-examples"},{"type":"function","title":"Returns - Alchemind.transcribe/3","doc":"- `{:ok, text}` - Successful transcription with text\n- `{:error, reason}` - Error with reason","ref":"Alchemind.html#transcribe/3-returns"},{"type":"callback","title":"Alchemind.transcribe/3","doc":"Transcribes audio to text.\n\nOptional callback that providers can implement to support audio transcription.","ref":"Alchemind.html#c:transcribe/3"},{"type":"extras","title":"Alchemind","doc":"# Alchemind\n\nCore library for the Alchemind project that provides interfaces, behaviors, and types for LLM interactions.","ref":"readme.html"},{"type":"extras","title":"Overview - Alchemind","doc":"This is the core package of the Alchemind umbrella application, containing the foundational components that all provider-specific implementations build upon. It defines the common interfaces and behaviors that ensure a consistent API across different LLM providers.","ref":"readme.html#overview"},{"type":"extras","title":"Features - Alchemind","doc":"- Common type definitions for LLM interactions\n- Behavior modules that provider implementations must conform to\n- Core utilities and helper functions","ref":"readme.html#features"},{"type":"extras","title":"Usage - Alchemind","doc":"This package is primarily used by other Alchemind packages and is not typically used directly. However, you can use the core interfaces to implement your own provider:\n\n```elixir\ndefmodule YourCustomProvider do\n  @behaviour Alchemind.Provider\n  \n  # Implement the required callbacks\n  # ...\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Alchemind","doc":"The package can be installed by adding `alchemind` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:alchemind, \"~> 0.1.0-rc1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Development - Alchemind","doc":"You can run tests specifically for this core package with:\n\n```bash\ncd apps/alchemind\nmix test\n```","ref":"readme.html#development"},{"type":"extras","title":"Documentation - Alchemind","doc":"Documentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc):\n\n```bash\ncd apps/alchemind\nmix docs\n```","ref":"readme.html#documentation"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025 Bradley Golden\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}